#!perl 

use Test::More tests => 1;

BEGIN {
	use_ok( 'Integrator::Test::TAP::Model::Patch' );
}

diag( "Testing Integrator::Test::TAP::Model::Patch $Integrator::Test::TAP::Model::Patch::VERSION, Perl $], $^X" );
